# (c) 2007 by Ralf Ertzinger <ralf@camperquake.de>
# licensed under GNU GPL v2
#
# Grabber for german-bash.org

package GermanBashGrabber;

use GrabberBase;
@ISA = qw(GrabberBase);

use LWP::Simple qw(!get);
use HTML::TokeParser;
use Data::Dumper;

use strict;

sub new {
    my $class = shift;
    my $self = $class->SUPER::new();

    $self->{'NAME'} = 'germanbash';
    $self->{'PATTERNS'} = ['(http://(?:[-a-zA-Z0-9_.]+\.)*german-bash\.org/(\d+))',
                           '(http://(?:[-a-zA-Z0-9_.]+\.)*german-bash\.org/action/show/id/(\d+))'];

    bless($self, $class);
    $self->_prepare_parameters();

    return $self;
}

sub _parse {
    my $self = shift;
    my $url = shift;
    my $pattern = shift;
    my $content;
    my $metadata = {};
    my $p;
    my $t;

    $url =~ m|$pattern|;
    $url = $1;

    $metadata->{'URL'} = $url;
    $metadata->{'ID'} = $2;
    $metadata->{'TYPE'} = 'quote';
    $metadata->{'SOURCE'} = $self->{'NAME'};
    $metadata->{'CONTENT'} = undef;

    # Get the HTML file containing the quote
    unless(defined($content = LWP::Simple::get(sprintf('http://german-bash.org/%s', $2)))) {
        $self->error('Could not download quote');
        return undef;
    }

    $p = HTML::TokeParser->new(\$content);

    while ($t = $p->get_tag('div')) {
        if (exists($t->[1]->{'class'}) && ($t->[1]->{'class'} eq 'zitat')) {
            $metadata->{'CONTENT'} = $p->get_text('/div');
            $metadata->{'CONTENT'} =~ s/^\s*//mg;
            last;
        }
    }

    unless(defined($metadata->{'CONTENT'})) {
        $self->error('Could not extract quote content');
        return undef;
    }

    return $metadata;
}

1;
